# Team

Meet the researchers and developers behind RHAPSODY.

## RADICAL Research Team

RHAPSODY is developed by the RADICAL Research Team at Rutgers University.

### Core Development Team

- Research scientists and engineers from the RADICAL group
- Graduate students and postdocs
- Collaborators from partner institutions

## Collaborators

RHAPSODY benefits from collaboration with:

- National laboratories
- Academic research institutions
- Industry partners
- Open source community contributors

## Contact

- **Website**: [https://radical.rutgers.edu/](https://radical.rutgers.edu/)
- **GitHub**: [https://github.com/radical-cybertools/rhapsody](https://github.com/radical-cybertools/rhapsody)

For more information about the project, see the [NSF Award](nsf-award.md) details.
